
# This file was generated by 'versioneer.py' (0.18) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2020-04-22T18:01:05+0100",
 "dirty": false,
 "error": null,
 "full-revisionid": "1ba325d9867a99d29a5f741482a6ed1fe36561b2",
 "version": "0.25.17"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
